// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "Scene.hpp"

using namespace Dawn;

Scene::Scene(
  const std::weak_ptr<Game> game,
  const std::function<void(Scene&)> sceneInitializer
) :
  game(game),
  sceneInitializer(sceneInitializer)
{

}

void Scene::stage() {
  Scene &selfReference = *this;
  sceneInitializer(selfReference);
}

std::shared_ptr<Game> Scene::getGame() {
  return game.lock();
}

std::shared_ptr<SceneItem> Scene::createSceneItem() {
  auto item = std::make_shared<SceneItem>(shared_from_this());
  sceneItems.push_back(item);
  return item;
}

Scene::~Scene() {
}