// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "scene/SceneItem.hpp"
#include "scene/Scene.hpp"

using namespace Dawn;

SceneItem::SceneItem(const std::weak_ptr<Scene> scene) :
  scene(scene),
  SceneItemTransform(),
  SceneItemComponents()
{
}

std::shared_ptr<SceneItem> SceneItem::sceneItemComponentsSelf() {
  return shared_from_this();
}

std::shared_ptr<Scene> SceneItem::getScene() {
  return scene.lock();
}

SceneItem::~SceneItem() {
  std::for_each(
    components.begin(),
    components.end(),
    [](auto &component) {
      component->dispose();
    }
  );
}